
#ifndef TRUE
#define TRUE  (0 == 0)
#endif

#ifndef FALSE
#define FALSE (0 == 1)
#endif

#define	bool  char		/* boolean type */
